Clazz.declarePackage("J.api.js");
Clazz.declareInterface(J.api.js, "JSConsole");
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
